/* $Id$

   Copyright (C) 2020 Ole Aamot Software
   Author(s): Ole Aamot <ole@gnome.org>
   License: GNU GPL version 3
   Version: 0.1.3 (2020-06-20)
   Website: http://www.gingerblue.org/

 */

#include <glib/gi18n.h>
#include <gtk/gtk.h>
#include <gtk/gtkbox.h>
#include <gtk/gtkbutton.h>
#include <gtk/gtkcontainer.h>
#include <gtk/gtkwindow.h>

#include <gst/gst.h>
#include "gingerblue.h"

GtkWidget *main_config (gchar *location_data) {
       GingerblueData *Gingerblue;
       GtkButton *AddStudioButton;
       GtkButton *NewStudioButton;
       GtkBox *Studio;
       GtkMisc *Location;
       GtkContainer *Container;
       GtkWindow *gingerblue;
       gingerblue = gtk_window_new (GTK_WINDOW_TOPLEVEL);
       gtk_window_set_title (GTK_WINDOW (gingerblue), _("Gingerblue Music Studio"));
       AddStudioButton = gtk_button_new_with_label(_("Add Studio"));
       NewStudioButton = gtk_button_new_with_label(_("New Studio"));
       Studio = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
       Location = gtk_list_box_new ();
       gtk_container_add (GTK_CONTAINER (gingerblue), GTK_WIDGET (Studio));
       gtk_box_pack_start (GTK_WIDGET (Studio), GTK_BUTTON (AddStudioButton), TRUE, TRUE, 0);
       gtk_box_pack_start (GTK_WIDGET (Studio), GTK_MISC (Location), TRUE, TRUE, 0);
       gtk_box_pack_start (GTK_WIDGET (Studio), GTK_BUTTON (NewStudioButton), TRUE, TRUE, 0);
       gtk_widget_show_all (GTK_WIDGET (gingerblue));
       return (GtkWidget *) gingerblue;
}
